/*
 * Copyright (c) 2006, David Peterson
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of "randombits.org" nor the names of its contributors
 *       may be used to endorse or promote products derived from this software
 *       without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.randombits.confluence.filtering.param.content;

import org.randombits.confluence.support.MacroInfo;
import org.randombits.confluence.filtering.param.ParameterException;
import com.atlassian.confluence.core.ConfluenceEntityObject;
import com.atlassian.confluence.core.ContentEntityObject;

/**
 * Returns the content entity linked to by the parameter. If the linked object
 * is not a ContentEntityObject, a parameter exception is thrown.
 * 
 * @author David Peterson
 */
public class ContentParameter extends ConfluenceEntityParameter {

    public ContentParameter( String defaultValue, String... names ) {
        super( defaultValue, names );
    }

    public ContentEntityObject findContent( MacroInfo info ) throws ParameterException {
        return ( ContentEntityObject ) findValue( info );
    }

    @Override protected ConfluenceEntityObject findObject( String paramValue, MacroInfo info )
            throws ParameterException {
        ConfluenceEntityObject entity = ( ConfluenceEntityObject ) super.findObject( paramValue, info );
        if ( entity instanceof ContentEntityObject )
            return entity;
        else if ( entity != null )
            throw new ParameterException( "The provided link does not point to a content object: " + paramValue );
        return null;
    }
}
